summary refs log tree commit diff
path: root/pkgs/tools/misc/grub/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/tools/misc/grub/default.nix')
-rw-r--r--pkgs/tools/misc/grub/default.nix11
1 files changed, 3 insertions, 8 deletions
diff --git a/pkgs/tools/misc/grub/default.nix b/pkgs/tools/misc/grub/default.nix
index cb561e8172fe..d6534fc5ee61 100644
--- a/pkgs/tools/misc/grub/default.nix
+++ b/pkgs/tools/misc/grub/default.nix
@@ -1,4 +1,4 @@
-{stdenv, fetchurl, autoconf, automake, texinfo, buggyBiosCDSupport ? true}:
+{stdenv, fetchurl, autoreconfHook, texinfo, buggyBiosCDSupport ? true}:
 
 stdenv.mkDerivation {
   name = "grub-0.97-patch-1.12";
@@ -33,8 +33,8 @@ stdenv.mkDerivation {
 
   ] ++ (stdenv.lib.optional buggyBiosCDSupport ./buggybios.patch);
 
-  # Autoconf/automake required for the splashimage patch.
-  buildInputs = [autoconf automake texinfo];
+  # autoreconfHook required for the splashimage patch.
+  buildInputs = [ autoreconfHook texinfo ];
 
   prePatch = ''
     unpackFile $gentooPatches
@@ -45,11 +45,6 @@ stdenv.mkDerivation {
     done
   '';
 
-  preConfigure = ''
-    autoreconf
-    automake --add-missing
-  '';
-
   passthru.grubTarget = "";
 
   meta = {